.. role:: hidden
    :class: hidden-section


botorch.exceptions
========================================================
.. automodule:: botorch.exceptions


Errors
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.exceptions.errors
    :members:

Warnings
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.exceptions.warnings
    :members:
